package server.messaging;

import java.io.Serializable;

/**
 * ResultMessage contains the output of the requested operation
 * from the server. In case the operation fails, an OperationException 
 * is attached to the message.
 */
public class ResultMessage implements Serializable{
	
	public static final int RES_TYPE_FAIL = 0;
	public static final int RES_TYPE_SUCCEED = 1;
	
	public static final int EXCEPTION_TYPE_UNKNOWN = 0;
	public static final int EXCEPTION_TYPE_QUEUE_DUPLICATION = 1;
	public static final int EXCEPTION_TYPE_QUEUE_EMPTY = 2;
	public static final int EXCEPTION_TYPE_QUEUE_FULL = 3;
	public static final int	EXCEPTION_TYPE_QUEUE_NOT_FOUND = 4;
	public static final int EXCEPTION_TYPE_MESSAGE_NULL = 5;
	
	private int messageNumber;
	private int resultType;
	private OperationException exception;
	private String message;
	
	public ResultMessage(int msgNr) {
		messageNumber = msgNr;
	}
	
	public void setResultType(int t) {
		resultType = t;
	}
	
	public int getResultType() {
		return resultType;
	}

	public int getMessageNumber() {
		return messageNumber;
	}
	
	public String getMessage() {
		return message;
	}
	
	public void setMessage(String data) {
		message = data;
	}
	
	public void addException(int type, String msg) {
		exception = new OperationException(type);
		exception.setMessage(msg);
	}
	
	public OperationException getException() {
		return exception;
	}
	
	public class OperationException implements Serializable{
		int type;
		String message;
		
		OperationException(int t) {
			type = t;
		}
		
		public int getType(){
			return type;
		}
		
		public String getMessage() {
			return message;
		}
		
		public void setMessage(String msg) {
			message = msg;
		}
	}
}
