package server.persist;

import java.io.File;
import java.io.IOException;
import java.util.Hashtable;

public class PersistDataMessageQueueManager{

	protected static PersistDataMessageQueueManager queueManager;
	protected static String queueDirectoryName= "queues"; // the directory where queue files locate

	private Hashtable queueList;
	private File queueDirectory;
	
	private PersistDataMessageQueueManager() {
		queueList = new Hashtable();
		initPersistStorage();
	}
	
	/**
	 * Individual queue is stored in the queue directory
	 * Check and read all the queue files, restore the states 
	 * of the queues.
	 */
	private void initPersistStorage() {
		queueDirectory = new File(queueDirectoryName);
		if (!queueDirectory.exists()) {
			queueDirectory.mkdir();
		} else {
			File[] qFiles = queueDirectory.listFiles();
			if (qFiles != null) {
				for (int i = 0; i < qFiles.length; i++) {
					File file = qFiles[i];
					String file_name = file.getName();
					if (file_name.endsWith(".que")) {
						String queue_name = file_name.substring(0, file_name.length() - 4);
						PersistDataMessageQueue queue = new PersistDataMessageQueue(queue_name);
						queueList.put(queue_name, queue);
					}
				}
			}
		}
	}

	public static PersistDataMessageQueueManager instance() {
		if (queueManager == null) {
			queueManager = new PersistDataMessageQueueManager();
		}
		return queueManager;
	}

	public boolean createQueue(String name) {
		if (queueList.containsKey(name)) {
			return false;
		} else {
			PersistDataMessageQueue q = new PersistDataMessageQueue(name);
			queueList.put(name, q);
			return true;
		}
	}

	public boolean deleteQueue(String name) {

		PersistDataMessageQueue q = (PersistDataMessageQueue) queueList.remove(name);
		if (q == null)
			return false;
		else {
			q.destroyPersistStorage();
			return true;
		}
	}

	public PersistDataMessageQueue getQueue(String name) {
		Object o = queueList.get(name);
		if (o == null)
			return null;
		else
			return ((PersistDataMessageQueue) o);
	}
}
